<template>
    <div  v-if="$hasRole('employee')">
        <!-- view task -->
        <TaskShow ref="taskShow"></TaskShow>
        <!-- view invoice -->
        <InvoiceShow ref="invoiceShow"></InvoiceShow>

        <v-btn text icon @click="dialog = true">
            <v-icon dark medium>event_available</v-icon>
        </v-btn>
        <v-row row justify-center>
            <v-dialog
                v-model="dialog"
                fullscreen
                hide-overlay
                transition="dialog-bottom-transition"
            >
                <v-card>
                    <v-toolbar dense flat>
                        <v-btn icon @click="dialog = false">
                            <v-icon>close</v-icon>
                        </v-btn>
                        <v-toolbar-title>
                            {{ trans('messages.calendar') }}
                        </v-toolbar-title>
                        <v-spacer></v-spacer>
                        <v-toolbar-items>
                            <v-chip label small color="#FF5252" class="mt-3 mr-1">
                                <v-icon left small>work_off</v-icon>
                                {{ trans('messages.leave') }}
                            </v-chip>
                            <v-chip label small color="#607D8B" class="mt-3 mr-1">
                                <v-icon left small>assessment</v-icon>
                                {{ trans('messages.project') }}
                            </v-chip>
                            <v-chip label small color="#795548" class="mt-3 mr-1">
                                <v-icon left small>assignment</v-icon>
                                {{ trans('messages.task') }}
                            </v-chip>
                            <v-chip label small color="#FF8A65" class="mt-3">
                                <v-icon left small>receipt</v-icon>
                                {{ trans('messages.invoice') }}
                            </v-chip>
                        </v-toolbar-items>
                    </v-toolbar>
                    <v-card-text>
                        <v-container >
                            <v-row>
                                <v-col xs="12" sm="3" md="3">
                                    <v-btn-toggle dark>
                                        <v-btn text @click="$refs.calendar.prev()">
                                            <v-icon>arrow_back_ios</v-icon>
                                            {{ trans('messages.prev') }}
                                        </v-btn>
                                        <v-btn text @click="$refs.calendar.next()">
                                            {{ trans('messages.next') }}
                                            <v-icon>arrow_forward_ios</v-icon>
                                        </v-btn>
                                    </v-btn-toggle>
                                </v-col>
                                <v-col xs="12" sm="6" md="6" class="text-center">
                                    <span class="display-1"> {{ calendarHeading }}</span>
                                </v-col>
                                <v-col xs="12" sm="3" md="3" class="text-right">
                                    <v-btn-toggle dark v-model="toggle_calendar_type">
                                        <v-btn text @click="type = 'month'">
                                            {{ trans('messages.month') }}
                                        </v-btn>
                                        <v-btn text @click="type = 'week'">
                                            {{ trans('messages.week') }}
                                        </v-btn>
                                        <v-btn text @click="type = 'day'">
                                            {{ trans('messages.day') }}
                                        </v-btn>
                                    </v-btn-toggle>
                                </v-col>
                            </v-row>
                            <v-divider></v-divider>
                            <v-row>
                                <v-col>
                                    <v-sheet height="520">
                                        <v-calendar
                                            ref="calendar"
                                            v-model="start"
                                            :type="type"
                                            :now="now"
                                            color="primary"
                                            @change="calendarChange"
                                            :events="calendarOverViews"
                                            :event-color="getEventColor"
                                            :event-more="event_more"
                                            @click:event="seeEvent"
                                            @click:more="viewDay"
                                            @click:date="viewDay"
                                        >
                                            
                                        </v-calendar>
                                    </v-sheet>
                                </v-col>
                            </v-row>
                        </v-container>
                    </v-card-text>
                </v-card>
            </v-dialog>
        </v-row>
    </div>
</template>
<script>
import TaskShow from '../projects/tasks/Show';
import InvoiceShow from '../projects/invoices/Show';
export default {
    components: {
        TaskShow,
        InvoiceShow,
    },
    data: () => ({
        type: 'month',
        start: moment()
            .startOf('month')
            .format('YYYY-MM-DD'),
        end: moment()
            .endOf('month')
            .format('YYYY-MM-DD'),
        now: moment(new Date()).format('YYYY-MM-DD'),
        typeOptions: [
            { text: 'Month', value: 'month' },
            { text: 'Week', value: 'week' },
            { text: 'Day', value: 'day' },
        ],
        calendarOverViews: [],
        calendarHeading: '',
        toggle_calendar_type: 0,
        dialog: false,
        event_more:false
    }),
    mounted() {
        var params = {};
        this.calendarHeading = moment(this.start).format('MMMM YYYY');
        params['start'] = this.start;
        params['end'] = this.end;
        this.getCalendarDatafromApi(params);
    },
    methods: {
        calendarChange(calendar) {
            var params = {};
            if (this.type === 'month') {
                this.calendarHeading = moment(calendar.start.date).format('MMMM YYYY');
            } else if (this.type === 'day') {
                this.calendarHeading = moment(calendar.start.date).format('MMMM DD, YYYY');
            } else if (this.type === 'week') {
                var heading = '';
                heading =
                    moment(calendar.start.date).format('MMMM DD, YYYY') +
                    ' - ' +
                    moment(calendar.end.date).format('MMMM DD, YYYY');
                this.calendarHeading = heading;
            }
            params['start'] = calendar.start.date;
            params['end'] = calendar.end.date;
            this.getCalendarDatafromApi(params);
        },
        getCalendarDatafromApi(params) {
            const self = this;
            axios
                .get('/calendar-overview', {
                    params: params,
                })
                .then(function(response) {
                    self.calendarOverViews = response.data;
                })
                .catch(function(error) {
                    console.log(error);
                });
        },
        getEventColor(event) {
            if (event.type === 'project') {
                return '#607D8B';
            } else if (event.type === 'task') {
                return '#795548';
            } else if (event.type === 'invoice') {
                return '#FF8A65';
            } else if (event.type === 'leave') {
                return '#FF5252';
            }
        },
        seeEvent({ nativeEvent, event }) {

            if (event.type === 'project') {
                this.dialog = false;
                this.$router.push({
                    name: 'projects.project-tasks.list',
                    params: { id: event.id },
                });
            } else if (event.type === 'task') {
                this.$refs.taskShow.view(event);
            } else if (event.type === 'invoice') {
                var data = { transaction_id: event.id, project_id: event.project_id };
                this.$refs.invoiceShow.view(data);
            }
        },
        viewDay({ date }) {
            this.start = date;
            this.type = 'day';
            this.toggle_calendar_type = 2;
        }
    },
};
</script>
